// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package cx aliases all exported identifiers in package
// "cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb".
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package cx

import (
	src "cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
const (
	AudioEncoding_AUDIO_ENCODING_AMR                               = src.AudioEncoding_AUDIO_ENCODING_AMR
	AudioEncoding_AUDIO_ENCODING_AMR_WB                            = src.AudioEncoding_AUDIO_ENCODING_AMR_WB
	AudioEncoding_AUDIO_ENCODING_FLAC                              = src.AudioEncoding_AUDIO_ENCODING_FLAC
	AudioEncoding_AUDIO_ENCODING_LINEAR_16                         = src.AudioEncoding_AUDIO_ENCODING_LINEAR_16
	AudioEncoding_AUDIO_ENCODING_MULAW                             = src.AudioEncoding_AUDIO_ENCODING_MULAW
	AudioEncoding_AUDIO_ENCODING_OGG_OPUS                          = src.AudioEncoding_AUDIO_ENCODING_OGG_OPUS
	AudioEncoding_AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE            = src.AudioEncoding_AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE
	AudioEncoding_AUDIO_ENCODING_UNSPECIFIED                       = src.AudioEncoding_AUDIO_ENCODING_UNSPECIFIED
	CalculateCoverageRequest_COVERAGE_TYPE_UNSPECIFIED             = src.CalculateCoverageRequest_COVERAGE_TYPE_UNSPECIFIED
	CalculateCoverageRequest_INTENT                                = src.CalculateCoverageRequest_INTENT
	CalculateCoverageRequest_PAGE_TRANSITION                       = src.CalculateCoverageRequest_PAGE_TRANSITION
	CalculateCoverageRequest_TRANSITION_ROUTE_GROUP                = src.CalculateCoverageRequest_TRANSITION_ROUTE_GROUP
	ContinuousTestResult_AGGREGATED_TEST_RESULT_UNSPECIFIED        = src.ContinuousTestResult_AGGREGATED_TEST_RESULT_UNSPECIFIED
	ContinuousTestResult_FAILED                                    = src.ContinuousTestResult_FAILED
	ContinuousTestResult_PASSED                                    = src.ContinuousTestResult_PASSED
	Deployment_FAILED                                              = src.Deployment_FAILED
	Deployment_RUNNING                                             = src.Deployment_RUNNING
	Deployment_STATE_UNSPECIFIED                                   = src.Deployment_STATE_UNSPECIFIED
	Deployment_SUCCEEDED                                           = src.Deployment_SUCCEEDED
	DetectIntentResponse_FINAL                                     = src.DetectIntentResponse_FINAL
	DetectIntentResponse_PARTIAL                                   = src.DetectIntentResponse_PARTIAL
	DetectIntentResponse_RESPONSE_TYPE_UNSPECIFIED                 = src.DetectIntentResponse_RESPONSE_TYPE_UNSPECIFIED
	EntityType_AUTO_EXPANSION_MODE_DEFAULT                         = src.EntityType_AUTO_EXPANSION_MODE_DEFAULT
	EntityType_AUTO_EXPANSION_MODE_UNSPECIFIED                     = src.EntityType_AUTO_EXPANSION_MODE_UNSPECIFIED
	EntityType_KIND_LIST                                           = src.EntityType_KIND_LIST
	EntityType_KIND_MAP                                            = src.EntityType_KIND_MAP
	EntityType_KIND_REGEXP                                         = src.EntityType_KIND_REGEXP
	EntityType_KIND_UNSPECIFIED                                    = src.EntityType_KIND_UNSPECIFIED
	Experiment_DONE                                                = src.Experiment_DONE
	Experiment_DRAFT                                               = src.Experiment_DRAFT
	Experiment_ROLLOUT_FAILED                                      = src.Experiment_ROLLOUT_FAILED
	Experiment_RUNNING                                             = src.Experiment_RUNNING
	Experiment_Result_ABANDONED_SESSION_RATE                       = src.Experiment_Result_ABANDONED_SESSION_RATE
	Experiment_Result_AVERAGE_TURN_COUNT                           = src.Experiment_Result_AVERAGE_TURN_COUNT
	Experiment_Result_CALLBACK_SESSION_RATE                        = src.Experiment_Result_CALLBACK_SESSION_RATE
	Experiment_Result_CONTAINED_SESSION_NO_CALLBACK_RATE           = src.Experiment_Result_CONTAINED_SESSION_NO_CALLBACK_RATE
	Experiment_Result_COUNT_TYPE_UNSPECIFIED                       = src.Experiment_Result_COUNT_TYPE_UNSPECIFIED
	Experiment_Result_LIVE_AGENT_HANDOFF_RATE                      = src.Experiment_Result_LIVE_AGENT_HANDOFF_RATE
	Experiment_Result_METRIC_UNSPECIFIED                           = src.Experiment_Result_METRIC_UNSPECIFIED
	Experiment_Result_SESSION_END_RATE                             = src.Experiment_Result_SESSION_END_RATE
	Experiment_Result_TOTAL_NO_MATCH_COUNT                         = src.Experiment_Result_TOTAL_NO_MATCH_COUNT
	Experiment_Result_TOTAL_TURN_COUNT                             = src.Experiment_Result_TOTAL_TURN_COUNT
	Experiment_STATE_UNSPECIFIED                                   = src.Experiment_STATE_UNSPECIFIED
	ExportAgentRequest_BLOB                                        = src.ExportAgentRequest_BLOB
	ExportAgentRequest_DATA_FORMAT_UNSPECIFIED                     = src.ExportAgentRequest_DATA_FORMAT_UNSPECIFIED
	ExportTestCasesRequest_BLOB                                    = src.ExportTestCasesRequest_BLOB
	ExportTestCasesRequest_DATA_FORMAT_UNSPECIFIED                 = src.ExportTestCasesRequest_DATA_FORMAT_UNSPECIFIED
	ExportTestCasesRequest_JSON                                    = src.ExportTestCasesRequest_JSON
	ImportFlowRequest_FALLBACK                                     = src.ImportFlowRequest_FALLBACK
	ImportFlowRequest_IMPORT_OPTION_UNSPECIFIED                    = src.ImportFlowRequest_IMPORT_OPTION_UNSPECIFIED
	ImportFlowRequest_KEEP                                         = src.ImportFlowRequest_KEEP
	IntentView_INTENT_VIEW_FULL                                    = src.IntentView_INTENT_VIEW_FULL
	IntentView_INTENT_VIEW_PARTIAL                                 = src.IntentView_INTENT_VIEW_PARTIAL
	IntentView_INTENT_VIEW_UNSPECIFIED                             = src.IntentView_INTENT_VIEW_UNSPECIFIED
	ListTestCasesRequest_BASIC                                     = src.ListTestCasesRequest_BASIC
	ListTestCasesRequest_FULL                                      = src.ListTestCasesRequest_FULL
	ListTestCasesRequest_TEST_CASE_VIEW_UNSPECIFIED                = src.ListTestCasesRequest_TEST_CASE_VIEW_UNSPECIFIED
	Match_DIRECT_INTENT                                            = src.Match_DIRECT_INTENT
	Match_EVENT                                                    = src.Match_EVENT
	Match_INTENT                                                   = src.Match_INTENT
	Match_MATCH_TYPE_UNSPECIFIED                                   = src.Match_MATCH_TYPE_UNSPECIFIED
	Match_NO_INPUT                                                 = src.Match_NO_INPUT
	Match_NO_MATCH                                                 = src.Match_NO_MATCH
	Match_PARAMETER_FILLING                                        = src.Match_PARAMETER_FILLING
	NluSettings_MODEL_TRAINING_MODE_AUTOMATIC                      = src.NluSettings_MODEL_TRAINING_MODE_AUTOMATIC
	NluSettings_MODEL_TRAINING_MODE_MANUAL                         = src.NluSettings_MODEL_TRAINING_MODE_MANUAL
	NluSettings_MODEL_TRAINING_MODE_UNSPECIFIED                    = src.NluSettings_MODEL_TRAINING_MODE_UNSPECIFIED
	NluSettings_MODEL_TYPE_ADVANCED                                = src.NluSettings_MODEL_TYPE_ADVANCED
	NluSettings_MODEL_TYPE_STANDARD                                = src.NluSettings_MODEL_TYPE_STANDARD
	NluSettings_MODEL_TYPE_UNSPECIFIED                             = src.NluSettings_MODEL_TYPE_UNSPECIFIED
	OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_LINEAR_16            = src.OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_LINEAR_16
	OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_MP3                  = src.OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_MP3
	OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_MP3_64_KBPS          = src.OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_MP3_64_KBPS
	OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_MULAW                = src.OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_MULAW
	OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_OGG_OPUS             = src.OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_OGG_OPUS
	OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_UNSPECIFIED          = src.OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_UNSPECIFIED
	PageInfo_FormInfo_ParameterInfo_EMPTY                          = src.PageInfo_FormInfo_ParameterInfo_EMPTY
	PageInfo_FormInfo_ParameterInfo_FILLED                         = src.PageInfo_FormInfo_ParameterInfo_FILLED
	PageInfo_FormInfo_ParameterInfo_INVALID                        = src.PageInfo_FormInfo_ParameterInfo_INVALID
	PageInfo_FormInfo_ParameterInfo_PARAMETER_STATE_UNSPECIFIED    = src.PageInfo_FormInfo_ParameterInfo_PARAMETER_STATE_UNSPECIFIED
	RestoreAgentRequest_FALLBACK                                   = src.RestoreAgentRequest_FALLBACK
	RestoreAgentRequest_KEEP                                       = src.RestoreAgentRequest_KEEP
	RestoreAgentRequest_RESTORE_OPTION_UNSPECIFIED                 = src.RestoreAgentRequest_RESTORE_OPTION_UNSPECIFIED
	SecuritySettings_AudioExportSettings_AUDIO_FORMAT_UNSPECIFIED  = src.SecuritySettings_AudioExportSettings_AUDIO_FORMAT_UNSPECIFIED
	SecuritySettings_AudioExportSettings_MP3                       = src.SecuritySettings_AudioExportSettings_MP3
	SecuritySettings_AudioExportSettings_MULAW                     = src.SecuritySettings_AudioExportSettings_MULAW
	SecuritySettings_AudioExportSettings_OGG                       = src.SecuritySettings_AudioExportSettings_OGG
	SecuritySettings_DIALOGFLOW_HISTORY                            = src.SecuritySettings_DIALOGFLOW_HISTORY
	SecuritySettings_PURGE_DATA_TYPE_UNSPECIFIED                   = src.SecuritySettings_PURGE_DATA_TYPE_UNSPECIFIED
	SecuritySettings_REDACTION_SCOPE_UNSPECIFIED                   = src.SecuritySettings_REDACTION_SCOPE_UNSPECIFIED
	SecuritySettings_REDACTION_STRATEGY_UNSPECIFIED                = src.SecuritySettings_REDACTION_STRATEGY_UNSPECIFIED
	SecuritySettings_REDACT_DISK_STORAGE                           = src.SecuritySettings_REDACT_DISK_STORAGE
	SecuritySettings_REDACT_WITH_SERVICE                           = src.SecuritySettings_REDACT_WITH_SERVICE
	SessionEntityType_ENTITY_OVERRIDE_MODE_OVERRIDE                = src.SessionEntityType_ENTITY_OVERRIDE_MODE_OVERRIDE
	SessionEntityType_ENTITY_OVERRIDE_MODE_SUPPLEMENT              = src.SessionEntityType_ENTITY_OVERRIDE_MODE_SUPPLEMENT
	SessionEntityType_ENTITY_OVERRIDE_MODE_UNSPECIFIED             = src.SessionEntityType_ENTITY_OVERRIDE_MODE_UNSPECIFIED
	SpeechModelVariant_SPEECH_MODEL_VARIANT_UNSPECIFIED            = src.SpeechModelVariant_SPEECH_MODEL_VARIANT_UNSPECIFIED
	SpeechModelVariant_USE_BEST_AVAILABLE                          = src.SpeechModelVariant_USE_BEST_AVAILABLE
	SpeechModelVariant_USE_ENHANCED                                = src.SpeechModelVariant_USE_ENHANCED
	SpeechModelVariant_USE_STANDARD                                = src.SpeechModelVariant_USE_STANDARD
	SsmlVoiceGender_SSML_VOICE_GENDER_FEMALE                       = src.SsmlVoiceGender_SSML_VOICE_GENDER_FEMALE
	SsmlVoiceGender_SSML_VOICE_GENDER_MALE                         = src.SsmlVoiceGender_SSML_VOICE_GENDER_MALE
	SsmlVoiceGender_SSML_VOICE_GENDER_NEUTRAL                      = src.SsmlVoiceGender_SSML_VOICE_GENDER_NEUTRAL
	SsmlVoiceGender_SSML_VOICE_GENDER_UNSPECIFIED                  = src.SsmlVoiceGender_SSML_VOICE_GENDER_UNSPECIFIED
	StreamingRecognitionResult_END_OF_SINGLE_UTTERANCE             = src.StreamingRecognitionResult_END_OF_SINGLE_UTTERANCE
	StreamingRecognitionResult_MESSAGE_TYPE_UNSPECIFIED            = src.StreamingRecognitionResult_MESSAGE_TYPE_UNSPECIFIED
	StreamingRecognitionResult_TRANSCRIPT                          = src.StreamingRecognitionResult_TRANSCRIPT
	TestResult_FAILED                                              = src.TestResult_FAILED
	TestResult_PASSED                                              = src.TestResult_PASSED
	TestResult_TEST_RESULT_UNSPECIFIED                             = src.TestResult_TEST_RESULT_UNSPECIFIED
	TestRunDifference_DIFF_TYPE_UNSPECIFIED                        = src.TestRunDifference_DIFF_TYPE_UNSPECIFIED
	TestRunDifference_INTENT                                       = src.TestRunDifference_INTENT
	TestRunDifference_PAGE                                         = src.TestRunDifference_PAGE
	TestRunDifference_PARAMETERS                                   = src.TestRunDifference_PARAMETERS
	TestRunDifference_UTTERANCE                                    = src.TestRunDifference_UTTERANCE
	ValidationMessage_AGENT                                        = src.ValidationMessage_AGENT
	ValidationMessage_ENTITY_TYPE                                  = src.ValidationMessage_ENTITY_TYPE
	ValidationMessage_ENTITY_TYPES                                 = src.ValidationMessage_ENTITY_TYPES
	ValidationMessage_ERROR                                        = src.ValidationMessage_ERROR
	ValidationMessage_FLOW                                         = src.ValidationMessage_FLOW
	ValidationMessage_INFO                                         = src.ValidationMessage_INFO
	ValidationMessage_INTENT                                       = src.ValidationMessage_INTENT
	ValidationMessage_INTENTS                                      = src.ValidationMessage_INTENTS
	ValidationMessage_INTENT_PARAMETER                             = src.ValidationMessage_INTENT_PARAMETER
	ValidationMessage_INTENT_TRAINING_PHRASE                       = src.ValidationMessage_INTENT_TRAINING_PHRASE
	ValidationMessage_INTENT_TRAINING_PHRASES                      = src.ValidationMessage_INTENT_TRAINING_PHRASES
	ValidationMessage_PAGE                                         = src.ValidationMessage_PAGE
	ValidationMessage_PAGES                                        = src.ValidationMessage_PAGES
	ValidationMessage_RESOURCE_TYPE_UNSPECIFIED                    = src.ValidationMessage_RESOURCE_TYPE_UNSPECIFIED
	ValidationMessage_SEVERITY_UNSPECIFIED                         = src.ValidationMessage_SEVERITY_UNSPECIFIED
	ValidationMessage_TRANSITION_ROUTE_GROUP                       = src.ValidationMessage_TRANSITION_ROUTE_GROUP
	ValidationMessage_WARNING                                      = src.ValidationMessage_WARNING
	ValidationMessage_WEBHOOK                                      = src.ValidationMessage_WEBHOOK
	Version_FAILED                                                 = src.Version_FAILED
	Version_RUNNING                                                = src.Version_RUNNING
	Version_STATE_UNSPECIFIED                                      = src.Version_STATE_UNSPECIFIED
	Version_SUCCEEDED                                              = src.Version_SUCCEEDED
	WebhookResponse_FulfillmentResponse_APPEND                     = src.WebhookResponse_FulfillmentResponse_APPEND
	WebhookResponse_FulfillmentResponse_MERGE_BEHAVIOR_UNSPECIFIED = src.WebhookResponse_FulfillmentResponse_MERGE_BEHAVIOR_UNSPECIFIED
	WebhookResponse_FulfillmentResponse_REPLACE                    = src.WebhookResponse_FulfillmentResponse_REPLACE
)

// Deprecated: Please use vars in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
var (
	AudioEncoding_name                                                   = src.AudioEncoding_name
	AudioEncoding_value                                                  = src.AudioEncoding_value
	CalculateCoverageRequest_CoverageType_name                           = src.CalculateCoverageRequest_CoverageType_name
	CalculateCoverageRequest_CoverageType_value                          = src.CalculateCoverageRequest_CoverageType_value
	ContinuousTestResult_AggregatedTestResult_name                       = src.ContinuousTestResult_AggregatedTestResult_name
	ContinuousTestResult_AggregatedTestResult_value                      = src.ContinuousTestResult_AggregatedTestResult_value
	Deployment_State_name                                                = src.Deployment_State_name
	Deployment_State_value                                               = src.Deployment_State_value
	DetectIntentResponse_ResponseType_name                               = src.DetectIntentResponse_ResponseType_name
	DetectIntentResponse_ResponseType_value                              = src.DetectIntentResponse_ResponseType_value
	EntityType_AutoExpansionMode_name                                    = src.EntityType_AutoExpansionMode_name
	EntityType_AutoExpansionMode_value                                   = src.EntityType_AutoExpansionMode_value
	EntityType_Kind_name                                                 = src.EntityType_Kind_name
	EntityType_Kind_value                                                = src.EntityType_Kind_value
	Experiment_Result_CountType_name                                     = src.Experiment_Result_CountType_name
	Experiment_Result_CountType_value                                    = src.Experiment_Result_CountType_value
	Experiment_Result_MetricType_name                                    = src.Experiment_Result_MetricType_name
	Experiment_Result_MetricType_value                                   = src.Experiment_Result_MetricType_value
	Experiment_State_name                                                = src.Experiment_State_name
	Experiment_State_value                                               = src.Experiment_State_value
	ExportAgentRequest_DataFormat_name                                   = src.ExportAgentRequest_DataFormat_name
	ExportAgentRequest_DataFormat_value                                  = src.ExportAgentRequest_DataFormat_value
	ExportTestCasesRequest_DataFormat_name                               = src.ExportTestCasesRequest_DataFormat_name
	ExportTestCasesRequest_DataFormat_value                              = src.ExportTestCasesRequest_DataFormat_value
	File_google_cloud_dialogflow_cx_v3beta1_advanced_settings_proto      = src.File_google_cloud_dialogflow_cx_v3beta1_advanced_settings_proto
	File_google_cloud_dialogflow_cx_v3beta1_agent_proto                  = src.File_google_cloud_dialogflow_cx_v3beta1_agent_proto
	File_google_cloud_dialogflow_cx_v3beta1_audio_config_proto           = src.File_google_cloud_dialogflow_cx_v3beta1_audio_config_proto
	File_google_cloud_dialogflow_cx_v3beta1_changelog_proto              = src.File_google_cloud_dialogflow_cx_v3beta1_changelog_proto
	File_google_cloud_dialogflow_cx_v3beta1_deployment_proto             = src.File_google_cloud_dialogflow_cx_v3beta1_deployment_proto
	File_google_cloud_dialogflow_cx_v3beta1_entity_type_proto            = src.File_google_cloud_dialogflow_cx_v3beta1_entity_type_proto
	File_google_cloud_dialogflow_cx_v3beta1_environment_proto            = src.File_google_cloud_dialogflow_cx_v3beta1_environment_proto
	File_google_cloud_dialogflow_cx_v3beta1_experiment_proto             = src.File_google_cloud_dialogflow_cx_v3beta1_experiment_proto
	File_google_cloud_dialogflow_cx_v3beta1_flow_proto                   = src.File_google_cloud_dialogflow_cx_v3beta1_flow_proto
	File_google_cloud_dialogflow_cx_v3beta1_fulfillment_proto            = src.File_google_cloud_dialogflow_cx_v3beta1_fulfillment_proto
	File_google_cloud_dialogflow_cx_v3beta1_intent_proto                 = src.File_google_cloud_dialogflow_cx_v3beta1_intent_proto
	File_google_cloud_dialogflow_cx_v3beta1_page_proto                   = src.File_google_cloud_dialogflow_cx_v3beta1_page_proto
	File_google_cloud_dialogflow_cx_v3beta1_response_message_proto       = src.File_google_cloud_dialogflow_cx_v3beta1_response_message_proto
	File_google_cloud_dialogflow_cx_v3beta1_security_settings_proto      = src.File_google_cloud_dialogflow_cx_v3beta1_security_settings_proto
	File_google_cloud_dialogflow_cx_v3beta1_session_entity_type_proto    = src.File_google_cloud_dialogflow_cx_v3beta1_session_entity_type_proto
	File_google_cloud_dialogflow_cx_v3beta1_session_proto                = src.File_google_cloud_dialogflow_cx_v3beta1_session_proto
	File_google_cloud_dialogflow_cx_v3beta1_test_case_proto              = src.File_google_cloud_dialogflow_cx_v3beta1_test_case_proto
	File_google_cloud_dialogflow_cx_v3beta1_transition_route_group_proto = src.File_google_cloud_dialogflow_cx_v3beta1_transition_route_group_proto
	File_google_cloud_dialogflow_cx_v3beta1_validation_message_proto     = src.File_google_cloud_dialogflow_cx_v3beta1_validation_message_proto
	File_google_cloud_dialogflow_cx_v3beta1_version_proto                = src.File_google_cloud_dialogflow_cx_v3beta1_version_proto
	File_google_cloud_dialogflow_cx_v3beta1_webhook_proto                = src.File_google_cloud_dialogflow_cx_v3beta1_webhook_proto
	ImportFlowRequest_ImportOption_name                                  = src.ImportFlowRequest_ImportOption_name
	ImportFlowRequest_ImportOption_value                                 = src.ImportFlowRequest_ImportOption_value
	IntentView_name                                                      = src.IntentView_name
	IntentView_value                                                     = src.IntentView_value
	ListTestCasesRequest_TestCaseView_name                               = src.ListTestCasesRequest_TestCaseView_name
	ListTestCasesRequest_TestCaseView_value                              = src.ListTestCasesRequest_TestCaseView_value
	Match_MatchType_name                                                 = src.Match_MatchType_name
	Match_MatchType_value                                                = src.Match_MatchType_value
	NluSettings_ModelTrainingMode_name                                   = src.NluSettings_ModelTrainingMode_name
	NluSettings_ModelTrainingMode_value                                  = src.NluSettings_ModelTrainingMode_value
	NluSettings_ModelType_name                                           = src.NluSettings_ModelType_name
	NluSettings_ModelType_value                                          = src.NluSettings_ModelType_value
	OutputAudioEncoding_name                                             = src.OutputAudioEncoding_name
	OutputAudioEncoding_value                                            = src.OutputAudioEncoding_value
	PageInfo_FormInfo_ParameterInfo_ParameterState_name                  = src.PageInfo_FormInfo_ParameterInfo_ParameterState_name
	PageInfo_FormInfo_ParameterInfo_ParameterState_value                 = src.PageInfo_FormInfo_ParameterInfo_ParameterState_value
	RestoreAgentRequest_RestoreOption_name                               = src.RestoreAgentRequest_RestoreOption_name
	RestoreAgentRequest_RestoreOption_value                              = src.RestoreAgentRequest_RestoreOption_value
	SecuritySettings_AudioExportSettings_AudioFormat_name                = src.SecuritySettings_AudioExportSettings_AudioFormat_name
	SecuritySettings_AudioExportSettings_AudioFormat_value               = src.SecuritySettings_AudioExportSettings_AudioFormat_value
	SecuritySettings_PurgeDataType_name                                  = src.SecuritySettings_PurgeDataType_name
	SecuritySettings_PurgeDataType_value                                 = src.SecuritySettings_PurgeDataType_value
	SecuritySettings_RedactionScope_name                                 = src.SecuritySettings_RedactionScope_name
	SecuritySettings_RedactionScope_value                                = src.SecuritySettings_RedactionScope_value
	SecuritySettings_RedactionStrategy_name                              = src.SecuritySettings_RedactionStrategy_name
	SecuritySettings_RedactionStrategy_value                             = src.SecuritySettings_RedactionStrategy_value
	SessionEntityType_EntityOverrideMode_name                            = src.SessionEntityType_EntityOverrideMode_name
	SessionEntityType_EntityOverrideMode_value                           = src.SessionEntityType_EntityOverrideMode_value
	SpeechModelVariant_name                                              = src.SpeechModelVariant_name
	SpeechModelVariant_value                                             = src.SpeechModelVariant_value
	SsmlVoiceGender_name                                                 = src.SsmlVoiceGender_name
	SsmlVoiceGender_value                                                = src.SsmlVoiceGender_value
	StreamingRecognitionResult_MessageType_name                          = src.StreamingRecognitionResult_MessageType_name
	StreamingRecognitionResult_MessageType_value                         = src.StreamingRecognitionResult_MessageType_value
	TestResult_name                                                      = src.TestResult_name
	TestResult_value                                                     = src.TestResult_value
	TestRunDifference_DiffType_name                                      = src.TestRunDifference_DiffType_name
	TestRunDifference_DiffType_value                                     = src.TestRunDifference_DiffType_value
	ValidationMessage_ResourceType_name                                  = src.ValidationMessage_ResourceType_name
	ValidationMessage_ResourceType_value                                 = src.ValidationMessage_ResourceType_value
	ValidationMessage_Severity_name                                      = src.ValidationMessage_Severity_name
	ValidationMessage_Severity_value                                     = src.ValidationMessage_Severity_value
	Version_State_name                                                   = src.Version_State_name
	Version_State_value                                                  = src.Version_State_value
	WebhookResponse_FulfillmentResponse_MergeBehavior_name               = src.WebhookResponse_FulfillmentResponse_MergeBehavior_name
	WebhookResponse_FulfillmentResponse_MergeBehavior_value              = src.WebhookResponse_FulfillmentResponse_MergeBehavior_value
)

// Hierarchical advanced settings for agent/flow/page/fulfillment/parameter.
// Settings exposed at lower level overrides the settings exposed at higher
// level. Overriding occurs at the sub-setting level. For example, the
// playback_interruption_settings at fulfillment level only overrides the
// playback_interruption_settings at the agent level, leaving other settings at
// the agent level unchanged. DTMF settings does not override each other. DTMF
// settings set at different levels define DTMF detections running in parallel.
// Hierarchy: Agent->Flow->Page->Fulfillment/Parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type AdvancedSettings = src.AdvancedSettings

// Define behaviors on logging.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type AdvancedSettings_LoggingSettings = src.AdvancedSettings_LoggingSettings

// Agents are best described as Natural Language Understanding (NLU) modules
// that transform user requests into actionable data. You can include agents in
// your app, product, or service to determine user intent and respond to the
// user in a natural way. After you create an agent, you can add
// [Intents][google.cloud.dialogflow.cx.v3beta1.Intent], [Entity
// Types][google.cloud.dialogflow.cx.v3beta1.EntityType],
// [Flows][google.cloud.dialogflow.cx.v3beta1.Flow],
// [Fulfillments][google.cloud.dialogflow.cx.v3beta1.Fulfillment],
// [Webhooks][google.cloud.dialogflow.cx.v3beta1.Webhook], and so on to manage
// the conversation flows..
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Agent = src.Agent

// The response message for
// [Agents.GetAgentValidationResult][google.cloud.dialogflow.cx.v3beta1.Agents.GetAgentValidationResult].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type AgentValidationResult = src.AgentValidationResult

// AgentsClient is the client API for Agents service. For semantics around ctx
// use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type AgentsClient = src.AgentsClient

// AgentsServer is the server API for Agents service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type AgentsServer = src.AgentsServer

// Audio encoding of the audio content sent in the conversational query
// request. Refer to the [Cloud Speech API
// documentation](https://cloud.google.com/speech-to-text/docs/basics) for more
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type AudioEncoding = src.AudioEncoding

// Represents the natural speech audio to be processed.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type AudioInput = src.AudioInput

// The request message for
// [TestCases.BatchDeleteTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.BatchDeleteTestCases].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type BatchDeleteTestCasesRequest = src.BatchDeleteTestCasesRequest

// Metadata returned for the
// [TestCases.BatchRunTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.BatchRunTestCases]
// long running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type BatchRunTestCasesMetadata = src.BatchRunTestCasesMetadata

// The request message for
// [TestCases.BatchRunTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.BatchRunTestCases].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type BatchRunTestCasesRequest = src.BatchRunTestCasesRequest

// The response message for
// [TestCases.BatchRunTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.BatchRunTestCases].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type BatchRunTestCasesResponse = src.BatchRunTestCasesResponse

// The request message for
// [TestCases.CalculateCoverage][google.cloud.dialogflow.cx.v3beta1.TestCases.CalculateCoverage].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CalculateCoverageRequest = src.CalculateCoverageRequest

// The type of coverage score requested.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CalculateCoverageRequest_CoverageType = src.CalculateCoverageRequest_CoverageType

// The response message for
// [TestCases.CalculateCoverage][google.cloud.dialogflow.cx.v3beta1.TestCases.CalculateCoverage].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CalculateCoverageResponse = src.CalculateCoverageResponse
type CalculateCoverageResponse_IntentCoverage = src.CalculateCoverageResponse_IntentCoverage
type CalculateCoverageResponse_RouteGroupCoverage = src.CalculateCoverageResponse_RouteGroupCoverage
type CalculateCoverageResponse_TransitionCoverage = src.CalculateCoverageResponse_TransitionCoverage

// Changelogs represents a change made to a given agent.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Changelog = src.Changelog

// ChangelogsClient is the client API for Changelogs service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ChangelogsClient = src.ChangelogsClient

// ChangelogsServer is the server API for Changelogs service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ChangelogsServer = src.ChangelogsServer

// The request message for
// [Versions.CompareVersions][google.cloud.dialogflow.cx.v3beta1.Versions.CompareVersions].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CompareVersionsRequest = src.CompareVersionsRequest

// The response message for
// [Versions.CompareVersions][google.cloud.dialogflow.cx.v3beta1.Versions.CompareVersions].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CompareVersionsResponse = src.CompareVersionsResponse

// Represents a result from running a test case in an agent environment.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ContinuousTestResult = src.ContinuousTestResult

// The overall result for a continuous test run in an agent environment.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ContinuousTestResult_AggregatedTestResult = src.ContinuousTestResult_AggregatedTestResult

// One interaction between a human and virtual agent. The human provides some
// input and the virtual agent provides a response.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ConversationTurn = src.ConversationTurn

// The input from the human user.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ConversationTurn_UserInput = src.ConversationTurn_UserInput

// The output from the virtual agent.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ConversationTurn_VirtualAgentOutput = src.ConversationTurn_VirtualAgentOutput

// The request message for
// [Agents.CreateAgent][google.cloud.dialogflow.cx.v3beta1.Agents.CreateAgent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateAgentRequest = src.CreateAgentRequest

// The request message for
// [EntityTypes.CreateEntityType][google.cloud.dialogflow.cx.v3beta1.EntityTypes.CreateEntityType].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateEntityTypeRequest = src.CreateEntityTypeRequest

// The request message for
// [Environments.CreateEnvironment][google.cloud.dialogflow.cx.v3beta1.Environments.CreateEnvironment].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateEnvironmentRequest = src.CreateEnvironmentRequest

// The request message for
// [Experiments.CreateExperiment][google.cloud.dialogflow.cx.v3beta1.Experiments.CreateExperiment].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateExperimentRequest = src.CreateExperimentRequest

// The request message for
// [Flows.CreateFlow][google.cloud.dialogflow.cx.v3beta1.Flows.CreateFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateFlowRequest = src.CreateFlowRequest

// The request message for
// [Intents.CreateIntent][google.cloud.dialogflow.cx.v3beta1.Intents.CreateIntent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateIntentRequest = src.CreateIntentRequest

// The request message for
// [Pages.CreatePage][google.cloud.dialogflow.cx.v3beta1.Pages.CreatePage].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreatePageRequest = src.CreatePageRequest

// The request message for [SecuritySettings.CreateSecuritySettings][].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateSecuritySettingsRequest = src.CreateSecuritySettingsRequest

// The request message for
// [SessionEntityTypes.CreateSessionEntityType][google.cloud.dialogflow.cx.v3beta1.SessionEntityTypes.CreateSessionEntityType].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateSessionEntityTypeRequest = src.CreateSessionEntityTypeRequest

// The request message for
// [TestCases.CreateTestCase][google.cloud.dialogflow.cx.v3beta1.TestCases.CreateTestCase].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateTestCaseRequest = src.CreateTestCaseRequest

// The request message for
// [TransitionRouteGroups.CreateTransitionRouteGroup][google.cloud.dialogflow.cx.v3beta1.TransitionRouteGroups.CreateTransitionRouteGroup].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateTransitionRouteGroupRequest = src.CreateTransitionRouteGroupRequest

// Metadata associated with the long running operation for
// [Versions.CreateVersion][google.cloud.dialogflow.cx.v3beta1.Versions.CreateVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateVersionOperationMetadata = src.CreateVersionOperationMetadata

// The request message for
// [Versions.CreateVersion][google.cloud.dialogflow.cx.v3beta1.Versions.CreateVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateVersionRequest = src.CreateVersionRequest

// The request message for
// [Webhooks.CreateWebhook][google.cloud.dialogflow.cx.v3beta1.Webhooks.CreateWebhook].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type CreateWebhookRequest = src.CreateWebhookRequest

// The request message for
// [Agents.DeleteAgent][google.cloud.dialogflow.cx.v3beta1.Agents.DeleteAgent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeleteAgentRequest = src.DeleteAgentRequest

// The request message for
// [EntityTypes.DeleteEntityType][google.cloud.dialogflow.cx.v3beta1.EntityTypes.DeleteEntityType].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeleteEntityTypeRequest = src.DeleteEntityTypeRequest

// The request message for
// [Environments.DeleteEnvironment][google.cloud.dialogflow.cx.v3beta1.Environments.DeleteEnvironment].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeleteEnvironmentRequest = src.DeleteEnvironmentRequest

// The request message for
// [Experiments.DeleteExperiment][google.cloud.dialogflow.cx.v3beta1.Experiments.DeleteExperiment].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeleteExperimentRequest = src.DeleteExperimentRequest

// The request message for
// [Flows.DeleteFlow][google.cloud.dialogflow.cx.v3beta1.Flows.DeleteFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeleteFlowRequest = src.DeleteFlowRequest

// The request message for
// [Intents.DeleteIntent][google.cloud.dialogflow.cx.v3beta1.Intents.DeleteIntent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeleteIntentRequest = src.DeleteIntentRequest

// The request message for
// [Pages.DeletePage][google.cloud.dialogflow.cx.v3beta1.Pages.DeletePage].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeletePageRequest = src.DeletePageRequest

// The request message for [SecuritySettings.DeleteSecuritySettings][].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeleteSecuritySettingsRequest = src.DeleteSecuritySettingsRequest

// The request message for
// [SessionEntityTypes.DeleteSessionEntityType][google.cloud.dialogflow.cx.v3beta1.SessionEntityTypes.DeleteSessionEntityType].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeleteSessionEntityTypeRequest = src.DeleteSessionEntityTypeRequest

// The request message for
// [TransitionRouteGroups.DeleteTransitionRouteGroup][google.cloud.dialogflow.cx.v3beta1.TransitionRouteGroups.DeleteTransitionRouteGroup].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeleteTransitionRouteGroupRequest = src.DeleteTransitionRouteGroupRequest

// The request message for
// [Versions.DeleteVersion][google.cloud.dialogflow.cx.v3beta1.Versions.DeleteVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeleteVersionRequest = src.DeleteVersionRequest

// The request message for
// [Webhooks.DeleteWebhook][google.cloud.dialogflow.cx.v3beta1.Webhooks.DeleteWebhook].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeleteWebhookRequest = src.DeleteWebhookRequest

// Metadata returned for the
// [Environments.DeployFlow][google.cloud.dialogflow.cx.v3beta1.Environments.DeployFlow]
// long running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeployFlowMetadata = src.DeployFlowMetadata

// The request message for
// [Environments.DeployFlow][google.cloud.dialogflow.cx.v3beta1.Environments.DeployFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeployFlowRequest = src.DeployFlowRequest

// The response message for
// [Environments.DeployFlow][google.cloud.dialogflow.cx.v3beta1.Environments.DeployFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeployFlowResponse = src.DeployFlowResponse

// Represents an deployment in an environment. A deployment happens when a
// flow version configured to be active in the environment. You can configure
// running pre-deployment steps, e.g. running validation test cases, experiment
// auto-rollout, etc.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Deployment = src.Deployment

// Result of the deployment.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Deployment_Result = src.Deployment_Result

// The state of the deployment.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Deployment_State = src.Deployment_State

// DeploymentsClient is the client API for Deployments service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeploymentsClient = src.DeploymentsClient

// DeploymentsServer is the server API for Deployments service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DeploymentsServer = src.DeploymentsServer

// The request to detect user's intent.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DetectIntentRequest = src.DetectIntentRequest

// The message returned from the DetectIntent method.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DetectIntentResponse = src.DetectIntentResponse

// Represents different DetectIntentResponse types.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DetectIntentResponse_ResponseType = src.DetectIntentResponse_ResponseType

// Represents the input for dtmf event.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type DtmfInput = src.DtmfInput

// Entities are extracted from user input and represent parameters that are
// meaningful to your application. For example, a date range, a proper name
// such as a geographic location or landmark, and so on. Entities represent
// actionable data for your application. When you define an entity, you can
// also include synonyms that all map to that entity. For example, "soft
// drink", "soda", "pop", and so on. There are three types of entities: -
// **System** - entities that are defined by the Dialogflow API for common data
// types such as date, time, currency, and so on. A system entity is
// represented by the `EntityType` type. - **Custom** - entities that are
// defined by you that represent actionable data that is meaningful to your
// application. For example, you could define a `pizza.sauce` entity for red or
// white pizza sauce, a `pizza.cheese` entity for the different types of cheese
// on a pizza, a `pizza.topping` entity for different toppings, and so on. A
// custom entity is represented by the `EntityType` type. - **User** - entities
// that are built for an individual user such as favorites, preferences,
// playlists, and so on. A user entity is represented by the
// [SessionEntityType][google.cloud.dialogflow.cx.v3beta1.SessionEntityType]
// type. For more information about entity types, see the [Dialogflow
// documentation](https://cloud.google.com/dialogflow/docs/entities-overview).
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type EntityType = src.EntityType

// Represents different entity type expansion modes. Automated expansion
// allows an agent to recognize values that have not been explicitly listed in
// the entity (for example, new kinds of shopping list items).
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type EntityType_AutoExpansionMode = src.EntityType_AutoExpansionMode

// An **entity entry** for an associated entity type.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type EntityType_Entity = src.EntityType_Entity

// An excluded entity phrase that should not be matched.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type EntityType_ExcludedPhrase = src.EntityType_ExcludedPhrase

// Represents kinds of entities.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type EntityType_Kind = src.EntityType_Kind

// EntityTypesClient is the client API for EntityTypes service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type EntityTypesClient = src.EntityTypesClient

// EntityTypesServer is the server API for EntityTypes service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type EntityTypesServer = src.EntityTypesServer

// Represents an environment for an agent. You can create multiple versions of
// your agent and publish them to separate environments. When you edit an
// agent, you are editing the draft agent. At any point, you can save the draft
// agent as an agent version, which is an immutable snapshot of your agent.
// When you save the draft agent, it is published to the default environment.
// When you create agent versions, you can publish them to custom environments.
// You can create a variety of custom environments for testing, development,
// production, etc.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Environment = src.Environment

// The configuration for continuous tests.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Environment_TestCasesConfig = src.Environment_TestCasesConfig

// Configuration for the version.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Environment_VersionConfig = src.Environment_VersionConfig

// Configuration for webhooks.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Environment_WebhookConfig = src.Environment_WebhookConfig

// EnvironmentsClient is the client API for Environments service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type EnvironmentsClient = src.EnvironmentsClient

// EnvironmentsServer is the server API for Environments service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type EnvironmentsServer = src.EnvironmentsServer

// An event handler specifies an
// [event][google.cloud.dialogflow.cx.v3beta1.EventHandler.event] that can be
// handled during a session. When the specified event happens, the following
// actions are taken in order: * If there is a
// [`trigger_fulfillment`][google.cloud.dialogflow.cx.v3beta1.EventHandler.trigger_fulfillment]
// associated with the event, it will be called. * If there is a
// [`target_page`][google.cloud.dialogflow.cx.v3beta1.EventHandler.target_page]
// associated with the event, the session will transition into the specified
// page. * If there is a
// [`target_flow`][google.cloud.dialogflow.cx.v3beta1.EventHandler.target_flow]
// associated with the event, the session will transition into the specified
// flow.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type EventHandler = src.EventHandler
type EventHandler_TargetFlow = src.EventHandler_TargetFlow
type EventHandler_TargetPage = src.EventHandler_TargetPage

// Represents the event to trigger.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type EventInput = src.EventInput

// Represents an experiment in an environment.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Experiment = src.Experiment

// Definition of the experiment.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Experiment_Definition = src.Experiment_Definition
type Experiment_Definition_VersionVariants = src.Experiment_Definition_VersionVariants

// The inference result which includes an objective metric to optimize and the
// confidence interval.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Experiment_Result = src.Experiment_Result

// A confidence interval is a range of possible values for the experiment
// objective you are trying to measure.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Experiment_Result_ConfidenceInterval = src.Experiment_Result_ConfidenceInterval

// types of count-based metric for Dialogflow experiment.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Experiment_Result_CountType = src.Experiment_Result_CountType

// Metric and corresponding confidence intervals.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Experiment_Result_Metric = src.Experiment_Result_Metric

// Types of ratio-based metric for Dialogflow experiment.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Experiment_Result_MetricType = src.Experiment_Result_MetricType
type Experiment_Result_Metric_Count = src.Experiment_Result_Metric_Count
type Experiment_Result_Metric_Ratio = src.Experiment_Result_Metric_Ratio

// Version variant and associated metrics.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Experiment_Result_VersionMetrics = src.Experiment_Result_VersionMetrics

// The state of the experiment.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Experiment_State = src.Experiment_State

// ExperimentsClient is the client API for Experiments service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ExperimentsClient = src.ExperimentsClient

// ExperimentsServer is the server API for Experiments service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ExperimentsServer = src.ExperimentsServer

// The request message for
// [Agents.ExportAgent][google.cloud.dialogflow.cx.v3beta1.Agents.ExportAgent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ExportAgentRequest = src.ExportAgentRequest

// Data format of the exported agent.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ExportAgentRequest_DataFormat = src.ExportAgentRequest_DataFormat

// The response message for
// [Agents.ExportAgent][google.cloud.dialogflow.cx.v3beta1.Agents.ExportAgent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ExportAgentResponse = src.ExportAgentResponse
type ExportAgentResponse_AgentContent = src.ExportAgentResponse_AgentContent
type ExportAgentResponse_AgentUri = src.ExportAgentResponse_AgentUri

// The request message for
// [Flows.ExportFlow][google.cloud.dialogflow.cx.v3beta1.Flows.ExportFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ExportFlowRequest = src.ExportFlowRequest

// The response message for
// [Flows.ExportFlow][google.cloud.dialogflow.cx.v3beta1.Flows.ExportFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ExportFlowResponse = src.ExportFlowResponse
type ExportFlowResponse_FlowContent = src.ExportFlowResponse_FlowContent
type ExportFlowResponse_FlowUri = src.ExportFlowResponse_FlowUri

// Metadata returned for the
// [TestCases.ExportTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.ExportTestCases]
// long running operation. This message currently has no fields.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ExportTestCasesMetadata = src.ExportTestCasesMetadata

// The request message for
// [TestCases.ExportTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.ExportTestCases].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ExportTestCasesRequest = src.ExportTestCasesRequest

// Data format of the exported test cases.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ExportTestCasesRequest_DataFormat = src.ExportTestCasesRequest_DataFormat
type ExportTestCasesRequest_GcsUri = src.ExportTestCasesRequest_GcsUri

// The response message for
// [TestCases.ExportTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.ExportTestCases].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ExportTestCasesResponse = src.ExportTestCasesResponse
type ExportTestCasesResponse_Content = src.ExportTestCasesResponse_Content
type ExportTestCasesResponse_GcsUri = src.ExportTestCasesResponse_GcsUri

// Flows represents the conversation flows when you build your chatbot agent.
// A flow consists of many pages connected by the transition routes.
// Conversations always start with the built-in Start Flow (with an all-0 ID).
// Transition routes can direct the conversation session from the current flow
// (parent flow) to another flow (sub flow). When the sub flow is finished,
// Dialogflow will bring the session back to the parent flow, where the sub
// flow is started. Usually, when a transition route is followed by a matched
// intent, the intent will be "consumed". This means the intent won't activate
// more transition routes. However, when the followed transition route moves
// the conversation session into a different flow, the matched intent can be
// carried over and to be consumed in the target flow.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Flow = src.Flow

// The response message for
// [Flows.GetFlowValidationResult][google.cloud.dialogflow.cx.v3beta1.Flows.GetFlowValidationResult].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type FlowValidationResult = src.FlowValidationResult

// FlowsClient is the client API for Flows service. For semantics around ctx
// use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type FlowsClient = src.FlowsClient

// FlowsServer is the server API for Flows service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type FlowsServer = src.FlowsServer

// A form is a data model that groups related parameters that can be collected
// from the user. The process in which the agent prompts the user and collects
// parameter values from the user is called form filling. A form can be added
// to a [page][google.cloud.dialogflow.cx.v3beta1.Page]. When form filling is
// done, the filled parameters will be written to the
// [session][google.cloud.dialogflow.cx.v3beta1.SessionInfo.parameters].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Form = src.Form

// Represents a form parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Form_Parameter = src.Form_Parameter

// Configuration for how the filling of a parameter should be handled.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Form_Parameter_FillBehavior = src.Form_Parameter_FillBehavior

// Request of [FulfillIntent][]
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type FulfillIntentRequest = src.FulfillIntentRequest

// Response of [FulfillIntent][]
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type FulfillIntentResponse = src.FulfillIntentResponse

// A fulfillment can do one or more of the following actions at the same time:
// - Generate rich message responses. - Set parameter values. - Call the
// webhook. Fulfillments can be called at various stages in the
// [Page][google.cloud.dialogflow.cx.v3beta1.Page] or
// [Form][google.cloud.dialogflow.cx.v3beta1.Form] lifecycle. For example, when
// a
// [DetectIntentRequest][google.cloud.dialogflow.cx.v3beta1.DetectIntentRequest]
// drives a session to enter a new page, the page's entry fulfillment can add a
// static response to the
// [QueryResult][google.cloud.dialogflow.cx.v3beta1.QueryResult] in the
// returning
// [DetectIntentResponse][google.cloud.dialogflow.cx.v3beta1.DetectIntentResponse],
// call the webhook (for example, to load user data from a database), or both.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Fulfillment = src.Fulfillment

// A list of cascading if-else conditions. Cases are mutually exclusive. The
// first one with a matching condition is selected, all the rest ignored.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Fulfillment_ConditionalCases = src.Fulfillment_ConditionalCases

// Each case has a Boolean condition. When it is evaluated to be True, the
// corresponding messages will be selected and evaluated recursively.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Fulfillment_ConditionalCases_Case = src.Fulfillment_ConditionalCases_Case

// The list of messages or conditional cases to activate for this case.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Fulfillment_ConditionalCases_Case_CaseContent = src.Fulfillment_ConditionalCases_Case_CaseContent
type Fulfillment_ConditionalCases_Case_CaseContent_AdditionalCases = src.Fulfillment_ConditionalCases_Case_CaseContent_AdditionalCases
type Fulfillment_ConditionalCases_Case_CaseContent_Message = src.Fulfillment_ConditionalCases_Case_CaseContent_Message

// Setting a parameter value.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Fulfillment_SetParameterAction = src.Fulfillment_SetParameterAction

// The request message for
// [Agents.GetAgent][google.cloud.dialogflow.cx.v3beta1.Agents.GetAgent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetAgentRequest = src.GetAgentRequest

// The request message for
// [Agents.GetAgentValidationResult][google.cloud.dialogflow.cx.v3beta1.Agents.GetAgentValidationResult].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetAgentValidationResultRequest = src.GetAgentValidationResultRequest

// The request message for
// [Changelogs.GetChangelog][google.cloud.dialogflow.cx.v3beta1.Changelogs.GetChangelog].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetChangelogRequest = src.GetChangelogRequest

// The request message for
// [Deployments.GetDeployment][google.cloud.dialogflow.cx.v3beta1.Deployments.GetDeployment].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetDeploymentRequest = src.GetDeploymentRequest

// The request message for
// [EntityTypes.GetEntityType][google.cloud.dialogflow.cx.v3beta1.EntityTypes.GetEntityType].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetEntityTypeRequest = src.GetEntityTypeRequest

// The request message for
// [Environments.GetEnvironment][google.cloud.dialogflow.cx.v3beta1.Environments.GetEnvironment].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetEnvironmentRequest = src.GetEnvironmentRequest

// The request message for
// [Experiments.GetExperiment][google.cloud.dialogflow.cx.v3beta1.Experiments.GetExperiment].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetExperimentRequest = src.GetExperimentRequest

// The response message for
// [Flows.GetFlow][google.cloud.dialogflow.cx.v3beta1.Flows.GetFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetFlowRequest = src.GetFlowRequest

// The request message for
// [Flows.GetFlowValidationResult][google.cloud.dialogflow.cx.v3beta1.Flows.GetFlowValidationResult].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetFlowValidationResultRequest = src.GetFlowValidationResultRequest

// The request message for
// [Intents.GetIntent][google.cloud.dialogflow.cx.v3beta1.Intents.GetIntent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetIntentRequest = src.GetIntentRequest

// The request message for
// [Pages.GetPage][google.cloud.dialogflow.cx.v3beta1.Pages.GetPage].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetPageRequest = src.GetPageRequest

// The request message for
// [SecuritySettingsService.GetSecuritySettings][google.cloud.dialogflow.cx.v3beta1.SecuritySettingsService.GetSecuritySettings].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetSecuritySettingsRequest = src.GetSecuritySettingsRequest

// The request message for
// [SessionEntityTypes.GetSessionEntityType][google.cloud.dialogflow.cx.v3beta1.SessionEntityTypes.GetSessionEntityType].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetSessionEntityTypeRequest = src.GetSessionEntityTypeRequest

// The request message for
// [TestCases.GetTestCase][google.cloud.dialogflow.cx.v3beta1.TestCases.GetTestCase].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetTestCaseRequest = src.GetTestCaseRequest

// The request message for
// [TestCases.GetTestCaseResult][google.cloud.dialogflow.cx.v3beta1.TestCases.GetTestCaseResult].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetTestCaseResultRequest = src.GetTestCaseResultRequest

// The request message for
// [TransitionRouteGroups.GetTransitionRouteGroup][google.cloud.dialogflow.cx.v3beta1.TransitionRouteGroups.GetTransitionRouteGroup].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetTransitionRouteGroupRequest = src.GetTransitionRouteGroupRequest

// The request message for
// [Versions.GetVersion][google.cloud.dialogflow.cx.v3beta1.Versions.GetVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetVersionRequest = src.GetVersionRequest

// The request message for
// [Webhooks.GetWebhook][google.cloud.dialogflow.cx.v3beta1.Webhooks.GetWebhook].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type GetWebhookRequest = src.GetWebhookRequest

// The request message for
// [Flows.ImportFlow][google.cloud.dialogflow.cx.v3beta1.Flows.ImportFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ImportFlowRequest = src.ImportFlowRequest
type ImportFlowRequest_FlowContent = src.ImportFlowRequest_FlowContent
type ImportFlowRequest_FlowUri = src.ImportFlowRequest_FlowUri

// Import option.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ImportFlowRequest_ImportOption = src.ImportFlowRequest_ImportOption

// The response message for
// [Flows.ImportFlow][google.cloud.dialogflow.cx.v3beta1.Flows.ImportFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ImportFlowResponse = src.ImportFlowResponse

// Metadata returned for the
// [TestCases.ImportTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.ImportTestCases]
// long running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ImportTestCasesMetadata = src.ImportTestCasesMetadata

// The request message for
// [TestCases.ImportTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.ImportTestCases].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ImportTestCasesRequest = src.ImportTestCasesRequest
type ImportTestCasesRequest_Content = src.ImportTestCasesRequest_Content
type ImportTestCasesRequest_GcsUri = src.ImportTestCasesRequest_GcsUri

// The response message for
// [TestCases.ImportTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.ImportTestCases].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ImportTestCasesResponse = src.ImportTestCasesResponse

// Instructs the speech recognizer on how to process the audio content.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type InputAudioConfig = src.InputAudioConfig

// An intent represents a user's intent to interact with a conversational
// agent. You can provide information for the Dialogflow API to use to match
// user input to an intent by adding training phrases (i.e., examples of user
// input) to your intent.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Intent = src.Intent

// Intent coverage represents the percentage of all possible intents in the
// agent that are triggered in any of a parent's test cases.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type IntentCoverage = src.IntentCoverage

// The agent's intent.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type IntentCoverage_Intent = src.IntentCoverage_Intent

// Represents the intent to trigger programmatically rather than as a result
// of natural language processing.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type IntentInput = src.IntentInput

// Represents the options for views of an intent. An intent can be a sizable
// object. Therefore, we provide a resource view that does not return training
// phrases in the response.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type IntentView = src.IntentView

// Represents an intent parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Intent_Parameter = src.Intent_Parameter

// Represents an example that the agent is trained on to identify the intent.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Intent_TrainingPhrase = src.Intent_TrainingPhrase

// Represents a part of a training phrase.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Intent_TrainingPhrase_Part = src.Intent_TrainingPhrase_Part

// IntentsClient is the client API for Intents service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type IntentsClient = src.IntentsClient

// IntentsServer is the server API for Intents service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type IntentsServer = src.IntentsServer

// The request message for
// [Agents.ListAgents][google.cloud.dialogflow.cx.v3beta1.Agents.ListAgents].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListAgentsRequest = src.ListAgentsRequest

// The response message for
// [Agents.ListAgents][google.cloud.dialogflow.cx.v3beta1.Agents.ListAgents].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListAgentsResponse = src.ListAgentsResponse

// The request message for
// [Changelogs.ListChangelogs][google.cloud.dialogflow.cx.v3beta1.Changelogs.ListChangelogs].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListChangelogsRequest = src.ListChangelogsRequest

// The response message for
// [Changelogs.ListChangelogs][google.cloud.dialogflow.cx.v3beta1.Changelogs.ListChangelogs].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListChangelogsResponse = src.ListChangelogsResponse

// The request message for
// [Environments.ListContinuousTestResults][google.cloud.dialogflow.cx.v3beta1.Environments.ListContinuousTestResults].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListContinuousTestResultsRequest = src.ListContinuousTestResultsRequest

// The response message for [Environments.ListTestCaseResults][].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListContinuousTestResultsResponse = src.ListContinuousTestResultsResponse

// The request message for
// [Deployments.ListDeployments][google.cloud.dialogflow.cx.v3beta1.Deployments.ListDeployments].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListDeploymentsRequest = src.ListDeploymentsRequest

// The response message for
// [Deployments.ListDeployments][google.cloud.dialogflow.cx.v3beta1.Deployments.ListDeployments].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListDeploymentsResponse = src.ListDeploymentsResponse

// The request message for
// [EntityTypes.ListEntityTypes][google.cloud.dialogflow.cx.v3beta1.EntityTypes.ListEntityTypes].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListEntityTypesRequest = src.ListEntityTypesRequest

// The response message for
// [EntityTypes.ListEntityTypes][google.cloud.dialogflow.cx.v3beta1.EntityTypes.ListEntityTypes].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListEntityTypesResponse = src.ListEntityTypesResponse

// The request message for
// [Environments.ListEnvironments][google.cloud.dialogflow.cx.v3beta1.Environments.ListEnvironments].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListEnvironmentsRequest = src.ListEnvironmentsRequest

// The response message for
// [Environments.ListEnvironments][google.cloud.dialogflow.cx.v3beta1.Environments.ListEnvironments].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListEnvironmentsResponse = src.ListEnvironmentsResponse

// The request message for
// [Experiments.ListExperiments][google.cloud.dialogflow.cx.v3beta1.Experiments.ListExperiments].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListExperimentsRequest = src.ListExperimentsRequest

// The response message for
// [Experiments.ListExperiments][google.cloud.dialogflow.cx.v3beta1.Experiments.ListExperiments].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListExperimentsResponse = src.ListExperimentsResponse

// The request message for
// [Flows.ListFlows][google.cloud.dialogflow.cx.v3beta1.Flows.ListFlows].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListFlowsRequest = src.ListFlowsRequest

// The response message for
// [Flows.ListFlows][google.cloud.dialogflow.cx.v3beta1.Flows.ListFlows].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListFlowsResponse = src.ListFlowsResponse

// The request message for
// [Intents.ListIntents][google.cloud.dialogflow.cx.v3beta1.Intents.ListIntents].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListIntentsRequest = src.ListIntentsRequest

// The response message for
// [Intents.ListIntents][google.cloud.dialogflow.cx.v3beta1.Intents.ListIntents].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListIntentsResponse = src.ListIntentsResponse

// The request message for
// [Pages.ListPages][google.cloud.dialogflow.cx.v3beta1.Pages.ListPages].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListPagesRequest = src.ListPagesRequest

// The response message for
// [Pages.ListPages][google.cloud.dialogflow.cx.v3beta1.Pages.ListPages].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListPagesResponse = src.ListPagesResponse

// The request message for [SecuritySettings.ListSecuritySettings][].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListSecuritySettingsRequest = src.ListSecuritySettingsRequest

// The response message for [SecuritySettings.ListSecuritySettings][].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListSecuritySettingsResponse = src.ListSecuritySettingsResponse

// The request message for
// [SessionEntityTypes.ListSessionEntityTypes][google.cloud.dialogflow.cx.v3beta1.SessionEntityTypes.ListSessionEntityTypes].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListSessionEntityTypesRequest = src.ListSessionEntityTypesRequest

// The response message for
// [SessionEntityTypes.ListSessionEntityTypes][google.cloud.dialogflow.cx.v3beta1.SessionEntityTypes.ListSessionEntityTypes].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListSessionEntityTypesResponse = src.ListSessionEntityTypesResponse

// The request message for
// [TestCases.ListTestCaseResults][google.cloud.dialogflow.cx.v3beta1.TestCases.ListTestCaseResults].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListTestCaseResultsRequest = src.ListTestCaseResultsRequest

// The response message for
// [TestCases.ListTestCaseResults][google.cloud.dialogflow.cx.v3beta1.TestCases.ListTestCaseResults].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListTestCaseResultsResponse = src.ListTestCaseResultsResponse

// The request message for
// [TestCases.ListTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.ListTestCases].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListTestCasesRequest = src.ListTestCasesRequest

// Specifies how much test case information to include in the response.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListTestCasesRequest_TestCaseView = src.ListTestCasesRequest_TestCaseView

// The response message for
// [TestCases.ListTestCases][google.cloud.dialogflow.cx.v3beta1.TestCases.ListTestCases].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListTestCasesResponse = src.ListTestCasesResponse

// The request message for
// [TransitionRouteGroups.ListTransitionRouteGroups][google.cloud.dialogflow.cx.v3beta1.TransitionRouteGroups.ListTransitionRouteGroups].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListTransitionRouteGroupsRequest = src.ListTransitionRouteGroupsRequest

// The response message for
// [TransitionRouteGroups.ListTransitionRouteGroups][google.cloud.dialogflow.cx.v3beta1.TransitionRouteGroups.ListTransitionRouteGroups].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListTransitionRouteGroupsResponse = src.ListTransitionRouteGroupsResponse

// The request message for
// [Versions.ListVersions][google.cloud.dialogflow.cx.v3beta1.Versions.ListVersions].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListVersionsRequest = src.ListVersionsRequest

// The response message for
// [Versions.ListVersions][google.cloud.dialogflow.cx.v3beta1.Versions.ListVersions].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListVersionsResponse = src.ListVersionsResponse

// The request message for
// [Webhooks.ListWebhooks][google.cloud.dialogflow.cx.v3beta1.Webhooks.ListWebhooks].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListWebhooksRequest = src.ListWebhooksRequest

// The response message for
// [Webhooks.ListWebhooks][google.cloud.dialogflow.cx.v3beta1.Webhooks.ListWebhooks].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ListWebhooksResponse = src.ListWebhooksResponse

// The request message for
// [Versions.LoadVersion][google.cloud.dialogflow.cx.v3beta1.Versions.LoadVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type LoadVersionRequest = src.LoadVersionRequest

// The request message for
// [Environments.LookupEnvironmentHistory][google.cloud.dialogflow.cx.v3beta1.Environments.LookupEnvironmentHistory].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type LookupEnvironmentHistoryRequest = src.LookupEnvironmentHistoryRequest

// The response message for
// [Environments.LookupEnvironmentHistory][google.cloud.dialogflow.cx.v3beta1.Environments.LookupEnvironmentHistory].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type LookupEnvironmentHistoryResponse = src.LookupEnvironmentHistoryResponse

// Represents one match result of [MatchIntent][].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Match = src.Match

// Request of [MatchIntent][].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type MatchIntentRequest = src.MatchIntentRequest

// Response of [MatchIntent][].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type MatchIntentResponse = src.MatchIntentResponse
type MatchIntentResponse_Text = src.MatchIntentResponse_Text
type MatchIntentResponse_Transcript = src.MatchIntentResponse_Transcript
type MatchIntentResponse_TriggerEvent = src.MatchIntentResponse_TriggerEvent
type MatchIntentResponse_TriggerIntent = src.MatchIntentResponse_TriggerIntent

// Type of a Match.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Match_MatchType = src.Match_MatchType

// Settings related to NLU.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type NluSettings = src.NluSettings

// NLU model training mode.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type NluSettings_ModelTrainingMode = src.NluSettings_ModelTrainingMode

// NLU model type.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type NluSettings_ModelType = src.NluSettings_ModelType

// Instructs the speech synthesizer how to generate the output audio content.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type OutputAudioConfig = src.OutputAudioConfig

// Audio encoding of the output audio format in Text-To-Speech.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type OutputAudioEncoding = src.OutputAudioEncoding

// A Dialogflow CX conversation (session) can be described and visualized as a
// state machine. The states of a CX session are represented by pages. For each
// flow, you define many pages, where your combined pages can handle a complete
// conversation on the topics the flow is designed for. At any given moment,
// exactly one page is the current page, the current page is considered active,
// and the flow associated with that page is considered active. Every flow has
// a special start page. When a flow initially becomes active, the start page
// page becomes the current page. For each conversational turn, the current
// page will either stay the same or transition to another page. You configure
// each page to collect information from the end-user that is relevant for the
// conversational state represented by the page. For more information, see the
// [Page guide](https://cloud.google.com/dialogflow/cx/docs/concept/page).
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Page = src.Page

// Represents page information communicated to and from the webhook.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type PageInfo = src.PageInfo

// Represents form information.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type PageInfo_FormInfo = src.PageInfo_FormInfo

// Represents parameter information.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type PageInfo_FormInfo_ParameterInfo = src.PageInfo_FormInfo_ParameterInfo

// Represents the state of a parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type PageInfo_FormInfo_ParameterInfo_ParameterState = src.PageInfo_FormInfo_ParameterInfo_ParameterState

// PagesClient is the client API for Pages service. For semantics around ctx
// use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type PagesClient = src.PagesClient

// PagesServer is the server API for Pages service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type PagesServer = src.PagesServer

// Represents the query input. It can contain one of: 1. A conversational
// query in the form of text. 2. An intent query that specifies which intent to
// trigger. 3. Natural language speech audio to be processed. 4. An event to be
// triggered.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type QueryInput = src.QueryInput
type QueryInput_Audio = src.QueryInput_Audio
type QueryInput_Dtmf = src.QueryInput_Dtmf
type QueryInput_Event = src.QueryInput_Event
type QueryInput_Intent = src.QueryInput_Intent
type QueryInput_Text = src.QueryInput_Text

// Represents the parameters of a conversational query.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type QueryParameters = src.QueryParameters

// Represents the result of a conversational query.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type QueryResult = src.QueryResult
type QueryResult_Dtmf = src.QueryResult_Dtmf
type QueryResult_Text = src.QueryResult_Text
type QueryResult_Transcript = src.QueryResult_Transcript
type QueryResult_TriggerEvent = src.QueryResult_TriggerEvent
type QueryResult_TriggerIntent = src.QueryResult_TriggerIntent

// Resource name and display name.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ResourceName = src.ResourceName

// Represents a response message that can be returned by a conversational
// agent. Response messages are also used for output audio synthesis. The
// approach is as follows: - If at least one OutputAudioText response is
// present, then all OutputAudioText responses are linearly concatenated, and
// the result is used for output audio synthesis. - If the OutputAudioText
// responses are a mixture of text and SSML, then the concatenated result is
// treated as SSML; otherwise, the result is treated as either text or SSML as
// appropriate. The agent designer should ideally use either text or SSML
// consistently throughout the bot design. - Otherwise, all Text responses are
// linearly concatenated, and the result is used for output audio synthesis.
// This approach allows for more sophisticated user experience scenarios, where
// the text displayed to the user may differ from what is heard.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ResponseMessage = src.ResponseMessage

// Indicates that the conversation succeeded, i.e., the bot handled the issue
// that the customer talked to it about. Dialogflow only uses this to determine
// which conversations should be counted as successful and doesn't process the
// metadata in this message in any way. Note that Dialogflow also considers
// conversations that get to the conversation end page as successful even if
// they don't return
// [ConversationSuccess][google.cloud.dialogflow.cx.v3beta1.ResponseMessage.ConversationSuccess].
// You may set this, for example: - In the
// [entry_fulfillment][google.cloud.dialogflow.cx.v3beta1.Page.entry_fulfillment]
// of a [Page][google.cloud.dialogflow.cx.v3beta1.Page] if entering the page
// indicates that the conversation succeeded. - In a webhook response when you
// determine that you handled the customer issue.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ResponseMessage_ConversationSuccess = src.ResponseMessage_ConversationSuccess
type ResponseMessage_ConversationSuccess_ = src.ResponseMessage_ConversationSuccess_

// Indicates that interaction with the Dialogflow agent has ended. This
// message is generated by Dialogflow only and not supposed to be defined by
// the user.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ResponseMessage_EndInteraction = src.ResponseMessage_EndInteraction
type ResponseMessage_EndInteraction_ = src.ResponseMessage_EndInteraction_

// Indicates that the conversation should be handed off to a live agent.
// Dialogflow only uses this to determine which conversations were handed off
// to a human agent for measurement purposes. What else to do with this signal
// is up to you and your handoff procedures. You may set this, for example: -
// In the
// [entry_fulfillment][google.cloud.dialogflow.cx.v3beta1.Page.entry_fulfillment]
// of a [Page][google.cloud.dialogflow.cx.v3beta1.Page] if entering the page
// indicates something went extremely wrong in the conversation. - In a webhook
// response when you determine that the customer issue can only be handled by a
// human.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ResponseMessage_LiveAgentHandoff = src.ResponseMessage_LiveAgentHandoff
type ResponseMessage_LiveAgentHandoff_ = src.ResponseMessage_LiveAgentHandoff_

// Represents an audio message that is composed of both segments synthesized
// from the Dialogflow agent prompts and ones hosted externally at the
// specified URIs. The external URIs are specified via
// [play_audio][google.cloud.dialogflow.cx.v3beta1.ResponseMessage.play_audio].
// This message is generated by Dialogflow only and not supposed to be defined
// by the user.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ResponseMessage_MixedAudio = src.ResponseMessage_MixedAudio
type ResponseMessage_MixedAudio_ = src.ResponseMessage_MixedAudio_

// Represents one segment of audio.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ResponseMessage_MixedAudio_Segment = src.ResponseMessage_MixedAudio_Segment
type ResponseMessage_MixedAudio_Segment_Audio = src.ResponseMessage_MixedAudio_Segment_Audio
type ResponseMessage_MixedAudio_Segment_Uri = src.ResponseMessage_MixedAudio_Segment_Uri

// A text or ssml response that is preferentially used for TTS output audio
// synthesis, as described in the comment on the ResponseMessage message.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ResponseMessage_OutputAudioText = src.ResponseMessage_OutputAudioText
type ResponseMessage_OutputAudioText_ = src.ResponseMessage_OutputAudioText_
type ResponseMessage_OutputAudioText_Ssml = src.ResponseMessage_OutputAudioText_Ssml
type ResponseMessage_OutputAudioText_Text = src.ResponseMessage_OutputAudioText_Text
type ResponseMessage_Payload = src.ResponseMessage_Payload

// Specifies an audio clip to be played by the client as part of the response.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ResponseMessage_PlayAudio = src.ResponseMessage_PlayAudio
type ResponseMessage_PlayAudio_ = src.ResponseMessage_PlayAudio_

// Represents the signal that telles the client to transfer the phone call
// connected to the agent to a third-party endpoint.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ResponseMessage_TelephonyTransferCall = src.ResponseMessage_TelephonyTransferCall
type ResponseMessage_TelephonyTransferCall_ = src.ResponseMessage_TelephonyTransferCall_
type ResponseMessage_TelephonyTransferCall_PhoneNumber = src.ResponseMessage_TelephonyTransferCall_PhoneNumber

// The text response message.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ResponseMessage_Text = src.ResponseMessage_Text
type ResponseMessage_Text_ = src.ResponseMessage_Text_

// The request message for
// [Agents.RestoreAgent][google.cloud.dialogflow.cx.v3beta1.Agents.RestoreAgent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type RestoreAgentRequest = src.RestoreAgentRequest
type RestoreAgentRequest_AgentContent = src.RestoreAgentRequest_AgentContent
type RestoreAgentRequest_AgentUri = src.RestoreAgentRequest_AgentUri

// Restore option.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type RestoreAgentRequest_RestoreOption = src.RestoreAgentRequest_RestoreOption

// The configuration for auto rollout.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type RolloutConfig = src.RolloutConfig

// A single rollout step with specified traffic allocation.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type RolloutConfig_RolloutStep = src.RolloutConfig_RolloutStep

// State of the auto-rollout process.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type RolloutState = src.RolloutState

// Metadata returned for the
// [Environments.RunContinuousTest][google.cloud.dialogflow.cx.v3beta1.Environments.RunContinuousTest]
// long running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type RunContinuousTestMetadata = src.RunContinuousTestMetadata

// The request message for
// [Environments.RunContinuousTest][google.cloud.dialogflow.cx.v3beta1.Environments.RunContinuousTest].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type RunContinuousTestRequest = src.RunContinuousTestRequest

// The response message for
// [Environments.RunContinuousTest][google.cloud.dialogflow.cx.v3beta1.Environments.RunContinuousTest].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type RunContinuousTestResponse = src.RunContinuousTestResponse

// Metadata returned for the
// [TestCases.RunTestCase][google.cloud.dialogflow.cx.v3beta1.TestCases.RunTestCase]
// long running operation. This message currently has no fields.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type RunTestCaseMetadata = src.RunTestCaseMetadata

// The request message for
// [TestCases.RunTestCase][google.cloud.dialogflow.cx.v3beta1.TestCases.RunTestCase].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type RunTestCaseRequest = src.RunTestCaseRequest

// The response message for
// [TestCases.RunTestCase][google.cloud.dialogflow.cx.v3beta1.TestCases.RunTestCase].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type RunTestCaseResponse = src.RunTestCaseResponse

// Represents the settings related to security issues, such as data redaction
// and data retention. It may take hours for updates on the settings to
// propagate to all the related components and take effect.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SecuritySettings = src.SecuritySettings

// SecuritySettingsServiceClient is the client API for SecuritySettingsService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SecuritySettingsServiceClient = src.SecuritySettingsServiceClient

// SecuritySettingsServiceServer is the server API for SecuritySettingsService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SecuritySettingsServiceServer = src.SecuritySettingsServiceServer

// Settings for exporting audio.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SecuritySettings_AudioExportSettings = src.SecuritySettings_AudioExportSettings

// File format for exported audio file. Currently only in telephony
// recordings.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SecuritySettings_AudioExportSettings_AudioFormat = src.SecuritySettings_AudioExportSettings_AudioFormat

// Settings for exporting conversations to
// [Insights](https://cloud.google.com/contact-center/insights/docs).
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SecuritySettings_InsightsExportSettings = src.SecuritySettings_InsightsExportSettings

// Type of data we purge after retention settings triggers purge.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SecuritySettings_PurgeDataType = src.SecuritySettings_PurgeDataType

// Defines what types of data to redact.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SecuritySettings_RedactionScope = src.SecuritySettings_RedactionScope

// Defines how we redact data.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SecuritySettings_RedactionStrategy = src.SecuritySettings_RedactionStrategy
type SecuritySettings_RetentionWindowDays = src.SecuritySettings_RetentionWindowDays

// The result of sentiment analysis. Sentiment analysis inspects user input
// and identifies the prevailing subjective opinion, especially to determine a
// user's attitude as positive, negative, or neutral.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SentimentAnalysisResult = src.SentimentAnalysisResult

// Session entity types are referred to as **User** entity types and are
// entities that are built for an individual user such as favorites,
// preferences, playlists, and so on. You can redefine a session entity type at
// the session level to extend or replace a [custom entity
// type][google.cloud.dialogflow.cx.v3beta1.EntityType] at the user session
// level (we refer to the entity types defined at the agent level as "custom
// entity types"). Note: session entity types apply to all queries, regardless
// of the language. For more information about entity types, see the
// [Dialogflow
// documentation](https://cloud.google.com/dialogflow/docs/entities-overview).
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SessionEntityType = src.SessionEntityType

// The types of modifications for the session entity type.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SessionEntityType_EntityOverrideMode = src.SessionEntityType_EntityOverrideMode

// SessionEntityTypesClient is the client API for SessionEntityTypes service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SessionEntityTypesClient = src.SessionEntityTypesClient

// SessionEntityTypesServer is the server API for SessionEntityTypes service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SessionEntityTypesServer = src.SessionEntityTypesServer

// Represents session information communicated to and from the webhook.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SessionInfo = src.SessionInfo

// SessionsClient is the client API for Sessions service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SessionsClient = src.SessionsClient

// SessionsServer is the server API for Sessions service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SessionsServer = src.SessionsServer
type Sessions_StreamingDetectIntentClient = src.Sessions_StreamingDetectIntentClient
type Sessions_StreamingDetectIntentServer = src.Sessions_StreamingDetectIntentServer

// Variant of the specified [Speech
// model][google.cloud.dialogflow.cx.v3beta1.InputAudioConfig.model] to use.
// See the [Cloud Speech
// documentation](https://cloud.google.com/speech-to-text/docs/enhanced-models)
// for which models have different variants. For example, the "phone_call"
// model has both a standard and an enhanced variant. When you use an enhanced
// model, you will generally receive higher quality results than for a standard
// model.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SpeechModelVariant = src.SpeechModelVariant

// Settings related to speech recognition.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SpeechToTextSettings = src.SpeechToTextSettings

// Information for a word recognized by the speech recognizer.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SpeechWordInfo = src.SpeechWordInfo

// Gender of the voice as described in [SSML voice
// element](https://www.w3.org/TR/speech-synthesis11/#edef_voice).
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SsmlVoiceGender = src.SsmlVoiceGender

// The request message for
// [Experiments.StartExperiment][google.cloud.dialogflow.cx.v3beta1.Experiments.StartExperiment].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type StartExperimentRequest = src.StartExperimentRequest

// The request message for
// [Experiments.StopExperiment][google.cloud.dialogflow.cx.v3beta1.Experiments.StopExperiment].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type StopExperimentRequest = src.StopExperimentRequest

// The top-level message sent by the client to the
// [Sessions.StreamingDetectIntent][google.cloud.dialogflow.cx.v3beta1.Sessions.StreamingDetectIntent]
// method. Multiple request messages should be sent in order: 1. The first
// message must contain
// [session][google.cloud.dialogflow.cx.v3beta1.StreamingDetectIntentRequest.session],
// [query_input][google.cloud.dialogflow.cx.v3beta1.StreamingDetectIntentRequest.query_input]
// plus optionally
// [query_params][google.cloud.dialogflow.cx.v3beta1.StreamingDetectIntentRequest.query_params].
// If the client wants to receive an audio response, it should also contain
// [output_audio_config][google.cloud.dialogflow.cx.v3beta1.StreamingDetectIntentRequest.output_audio_config].
// 2. If
// [query_input][google.cloud.dialogflow.cx.v3beta1.StreamingDetectIntentRequest.query_input]
// was set to
// [query_input.audio.config][google.cloud.dialogflow.cx.v3beta1.AudioInput.config],
// all subsequent messages must contain
// [query_input.audio.audio][google.cloud.dialogflow.cx.v3beta1.AudioInput.audio]
// to continue with Speech recognition. If you decide to rather detect an
// intent from text input after you already started Speech recognition, please
// send a message with
// [query_input.text][google.cloud.dialogflow.cx.v3beta1.QueryInput.text].
// However, note that: * Dialogflow will bill you for the audio duration so
// far. * Dialogflow discards all Speech recognition results in favor of the
// input text. * Dialogflow will use the language code from the first message.
// After you sent all input, you must half-close or abort the request stream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type StreamingDetectIntentRequest = src.StreamingDetectIntentRequest

// The top-level message returned from the
// [StreamingDetectIntent][google.cloud.dialogflow.cx.v3beta1.Sessions.StreamingDetectIntent]
// method. Multiple response messages (N) can be returned in order. The first
// (N-1) responses set either the `recognition_result` or
// `detect_intent_response` field, depending on the request: - If the
// `StreamingDetectIntentRequest.query_input.audio` field was set, and the
// `StreamingDetectIntentRequest.enable_partial_response` field was false, the
// `recognition_result` field is populated for each of the (N-1) responses. See
// the
// [StreamingRecognitionResult][google.cloud.dialogflow.cx.v3beta1.StreamingRecognitionResult]
// message for details about the result message sequence. - If the
// `StreamingDetectIntentRequest.enable_partial_response` field was true, the
// `detect_intent_response` field is populated for each of the (N-1) responses,
// where 1 <= N <= 4. These responses set the
// [DetectIntentResponse.response_type][google.cloud.dialogflow.cx.v3beta1.DetectIntentResponse.response_type]
// field to `PARTIAL`. For the final Nth response message, the
// `detect_intent_response` is fully populated, and
// [DetectIntentResponse.response_type][google.cloud.dialogflow.cx.v3beta1.DetectIntentResponse.response_type]
// is set to `FINAL`.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type StreamingDetectIntentResponse = src.StreamingDetectIntentResponse
type StreamingDetectIntentResponse_DetectIntentResponse = src.StreamingDetectIntentResponse_DetectIntentResponse
type StreamingDetectIntentResponse_RecognitionResult = src.StreamingDetectIntentResponse_RecognitionResult

// Contains a speech recognition result corresponding to a portion of the
// audio that is currently being processed or an indication that this is the
// end of the single requested utterance. While end-user audio is being
// processed, Dialogflow sends a series of results. Each result may contain a
// `transcript` value. A transcript represents a portion of the utterance.
// While the recognizer is processing audio, transcript values may be interim
// values or finalized values. Once a transcript is finalized, the `is_final`
// value is set to true and processing continues for the next transcript. If
// `StreamingDetectIntentRequest.query_input.audio.config.single_utterance` was
// true, and the recognizer has completed processing audio, the `message_type`
// value is set to `END_OF_SINGLE_UTTERANCE and the following (last) result
// contains the last finalized transcript. The complete end-user utterance is
// determined by concatenating the finalized transcript values received for the
// series of results. In the following example, single utterance is enabled. In
// the case where single utterance is not enabled, result 7 would not occur.
// ``` Num | transcript | message_type | is_final --- | -----------------------
// | ----------------------- | -------- 1 | "tube" | TRANSCRIPT | false 2 | "to
// be a" | TRANSCRIPT | false 3 | "to be" | TRANSCRIPT | false 4 | "to be or
// not to be" | TRANSCRIPT | true 5 | "that's" | TRANSCRIPT | false 6 | "that
// is | TRANSCRIPT | false 7 | unset | END_OF_SINGLE_UTTERANCE | unset 8 | "
// that is the question" | TRANSCRIPT | true ``` Concatenating the finalized
// transcripts with `is_final` set to true, the complete utterance becomes "to
// be or not to be that is the question".
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type StreamingRecognitionResult = src.StreamingRecognitionResult

// Type of the response message.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type StreamingRecognitionResult_MessageType = src.StreamingRecognitionResult_MessageType

// Configuration of how speech should be synthesized.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type SynthesizeSpeechConfig = src.SynthesizeSpeechConfig

// Represents a test case.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TestCase = src.TestCase

// Error info for importing a test.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TestCaseError = src.TestCaseError

// Represents a result from running a test case in an agent environment.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TestCaseResult = src.TestCaseResult

// TestCasesClient is the client API for TestCases service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TestCasesClient = src.TestCasesClient

// TestCasesServer is the server API for TestCases service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TestCasesServer = src.TestCasesServer

// Represents configurations for a test case.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TestConfig = src.TestConfig

// Error info for running a test.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TestError = src.TestError

// The test result for a test case and an agent environment.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TestResult = src.TestResult

// The description of differences between original and replayed agent output.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TestRunDifference = src.TestRunDifference

// What part of the message replay differs from the test case.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TestRunDifference_DiffType = src.TestRunDifference_DiffType

// Represents the natural language text to be processed.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TextInput = src.TextInput

// The request message for
// [Flows.TrainFlow][google.cloud.dialogflow.cx.v3beta1.Flows.TrainFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TrainFlowRequest = src.TrainFlowRequest

// Transition coverage represents the percentage of all possible page
// transitions (page-level transition routes and event handlers, excluding
// transition route groups) present within any of a parent's test cases.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TransitionCoverage = src.TransitionCoverage

// A transition in a page.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TransitionCoverage_Transition = src.TransitionCoverage_Transition

// The source or target of a transition.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TransitionCoverage_TransitionNode = src.TransitionCoverage_TransitionNode
type TransitionCoverage_TransitionNode_Flow = src.TransitionCoverage_TransitionNode_Flow
type TransitionCoverage_TransitionNode_Page = src.TransitionCoverage_TransitionNode_Page
type TransitionCoverage_Transition_EventHandler = src.TransitionCoverage_Transition_EventHandler
type TransitionCoverage_Transition_TransitionRoute = src.TransitionCoverage_Transition_TransitionRoute

// A transition route specifies a
// [intent][google.cloud.dialogflow.cx.v3beta1.Intent] that can be matched
// and/or a data condition that can be evaluated during a session. When a
// specified transition is matched, the following actions are taken in order: *
// If there is a
// [`trigger_fulfillment`][google.cloud.dialogflow.cx.v3beta1.TransitionRoute.trigger_fulfillment]
// associated with the transition, it will be called. * If there is a
// [`target_page`][google.cloud.dialogflow.cx.v3beta1.TransitionRoute.target_page]
// associated with the transition, the session will transition into the
// specified page. * If there is a
// [`target_flow`][google.cloud.dialogflow.cx.v3beta1.TransitionRoute.target_flow]
// associated with the transition, the session will transition into the
// specified flow.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TransitionRoute = src.TransitionRoute

// An TransitionRouteGroup represents a group of
// [`TransitionRoutes`][google.cloud.dialogflow.cx.v3beta1.TransitionRoute] to
// be used by a [Page][google.cloud.dialogflow.cx.v3beta1.Page].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TransitionRouteGroup = src.TransitionRouteGroup

// Transition route group coverage represents the percentage of all possible
// transition routes present within any of a parent's test cases. The results
// are grouped by the transition route group.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TransitionRouteGroupCoverage = src.TransitionRouteGroupCoverage

// Coverage result message for one transition route group.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TransitionRouteGroupCoverage_Coverage = src.TransitionRouteGroupCoverage_Coverage

// A transition coverage in a transition route group.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TransitionRouteGroupCoverage_Coverage_Transition = src.TransitionRouteGroupCoverage_Coverage_Transition

// TransitionRouteGroupsClient is the client API for TransitionRouteGroups
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TransitionRouteGroupsClient = src.TransitionRouteGroupsClient

// TransitionRouteGroupsServer is the server API for TransitionRouteGroups
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type TransitionRouteGroupsServer = src.TransitionRouteGroupsServer
type TransitionRoute_TargetFlow = src.TransitionRoute_TargetFlow
type TransitionRoute_TargetPage = src.TransitionRoute_TargetPage

// UnimplementedAgentsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedAgentsServer = src.UnimplementedAgentsServer

// UnimplementedChangelogsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedChangelogsServer = src.UnimplementedChangelogsServer

// UnimplementedDeploymentsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedDeploymentsServer = src.UnimplementedDeploymentsServer

// UnimplementedEntityTypesServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedEntityTypesServer = src.UnimplementedEntityTypesServer

// UnimplementedEnvironmentsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedEnvironmentsServer = src.UnimplementedEnvironmentsServer

// UnimplementedExperimentsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedExperimentsServer = src.UnimplementedExperimentsServer

// UnimplementedFlowsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedFlowsServer = src.UnimplementedFlowsServer

// UnimplementedIntentsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedIntentsServer = src.UnimplementedIntentsServer

// UnimplementedPagesServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedPagesServer = src.UnimplementedPagesServer

// UnimplementedSecuritySettingsServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedSecuritySettingsServiceServer = src.UnimplementedSecuritySettingsServiceServer

// UnimplementedSessionEntityTypesServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedSessionEntityTypesServer = src.UnimplementedSessionEntityTypesServer

// UnimplementedSessionsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedSessionsServer = src.UnimplementedSessionsServer

// UnimplementedTestCasesServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedTestCasesServer = src.UnimplementedTestCasesServer

// UnimplementedTransitionRouteGroupsServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedTransitionRouteGroupsServer = src.UnimplementedTransitionRouteGroupsServer

// UnimplementedVersionsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedVersionsServer = src.UnimplementedVersionsServer

// UnimplementedWebhooksServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UnimplementedWebhooksServer = src.UnimplementedWebhooksServer

// The request message for
// [Agents.UpdateAgent][google.cloud.dialogflow.cx.v3beta1.Agents.UpdateAgent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateAgentRequest = src.UpdateAgentRequest

// The request message for
// [EntityTypes.UpdateEntityType][google.cloud.dialogflow.cx.v3beta1.EntityTypes.UpdateEntityType].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateEntityTypeRequest = src.UpdateEntityTypeRequest

// The request message for
// [Environments.UpdateEnvironment][google.cloud.dialogflow.cx.v3beta1.Environments.UpdateEnvironment].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateEnvironmentRequest = src.UpdateEnvironmentRequest

// The request message for
// [Experiments.UpdateExperiment][google.cloud.dialogflow.cx.v3beta1.Experiments.UpdateExperiment].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateExperimentRequest = src.UpdateExperimentRequest

// The request message for
// [Flows.UpdateFlow][google.cloud.dialogflow.cx.v3beta1.Flows.UpdateFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateFlowRequest = src.UpdateFlowRequest

// The request message for
// [Intents.UpdateIntent][google.cloud.dialogflow.cx.v3beta1.Intents.UpdateIntent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateIntentRequest = src.UpdateIntentRequest

// The request message for
// [Pages.UpdatePage][google.cloud.dialogflow.cx.v3beta1.Pages.UpdatePage].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdatePageRequest = src.UpdatePageRequest

// The request message for
// [SecuritySettingsService.UpdateSecuritySettings][google.cloud.dialogflow.cx.v3beta1.SecuritySettingsService.UpdateSecuritySettings].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateSecuritySettingsRequest = src.UpdateSecuritySettingsRequest

// The request message for
// [SessionEntityTypes.UpdateSessionEntityType][google.cloud.dialogflow.cx.v3beta1.SessionEntityTypes.UpdateSessionEntityType].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateSessionEntityTypeRequest = src.UpdateSessionEntityTypeRequest

// The request message for
// [TestCases.UpdateTestCase][google.cloud.dialogflow.cx.v3beta1.TestCases.UpdateTestCase].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateTestCaseRequest = src.UpdateTestCaseRequest

// The request message for
// [TransitionRouteGroups.UpdateTransitionRouteGroup][google.cloud.dialogflow.cx.v3beta1.TransitionRouteGroups.UpdateTransitionRouteGroup].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateTransitionRouteGroupRequest = src.UpdateTransitionRouteGroupRequest

// The request message for
// [Versions.UpdateVersion][google.cloud.dialogflow.cx.v3beta1.Versions.UpdateVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateVersionRequest = src.UpdateVersionRequest

// The request message for
// [Webhooks.UpdateWebhook][google.cloud.dialogflow.cx.v3beta1.Webhooks.UpdateWebhook].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type UpdateWebhookRequest = src.UpdateWebhookRequest

// The request message for
// [Agents.ValidateAgent][google.cloud.dialogflow.cx.v3beta1.Agents.ValidateAgent].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ValidateAgentRequest = src.ValidateAgentRequest

// The request message for
// [Flows.ValidateFlow][google.cloud.dialogflow.cx.v3beta1.Flows.ValidateFlow].
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ValidateFlowRequest = src.ValidateFlowRequest

// Agent/flow validation message.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ValidationMessage = src.ValidationMessage

// Resource types.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ValidationMessage_ResourceType = src.ValidationMessage_ResourceType

// Severity level.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type ValidationMessage_Severity = src.ValidationMessage_Severity

// The history of variants update.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type VariantsHistory = src.VariantsHistory
type VariantsHistory_VersionVariants = src.VariantsHistory_VersionVariants

// Represents a version of a flow.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Version = src.Version

// A list of flow version variants.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type VersionVariants = src.VersionVariants

// A single flow version with specified traffic allocation.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type VersionVariants_Variant = src.VersionVariants_Variant

// The state of the version.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Version_State = src.Version_State

// VersionsClient is the client API for Versions service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type VersionsClient = src.VersionsClient

// VersionsServer is the server API for Versions service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type VersionsServer = src.VersionsServer

// Description of which voice to use for speech synthesis.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type VoiceSelectionParams = src.VoiceSelectionParams

// Webhooks host the developer's business logic. During a session, webhooks
// allow the developer to use the data extracted by Dialogflow's natural
// language processing to generate dynamic responses, validate collected data,
// or trigger actions on the backend.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Webhook = src.Webhook

// The request message for a webhook call. The request is sent as a JSON
// object and the field names will be presented in camel cases. You may see
// undocumented fields in an actual request. These fields are used internally
// by Dialogflow and should be ignored.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type WebhookRequest = src.WebhookRequest

// Represents fulfillment information communicated to the webhook.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type WebhookRequest_FulfillmentInfo = src.WebhookRequest_FulfillmentInfo

// Represents intent information communicated to the webhook.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type WebhookRequest_IntentInfo = src.WebhookRequest_IntentInfo

// Represents a value for an intent parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type WebhookRequest_IntentInfo_IntentParameterValue = src.WebhookRequest_IntentInfo_IntentParameterValue

// Represents the result of sentiment analysis.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type WebhookRequest_SentimentAnalysisResult = src.WebhookRequest_SentimentAnalysisResult
type WebhookRequest_Text = src.WebhookRequest_Text
type WebhookRequest_Transcript = src.WebhookRequest_Transcript
type WebhookRequest_TriggerEvent = src.WebhookRequest_TriggerEvent
type WebhookRequest_TriggerIntent = src.WebhookRequest_TriggerIntent

// The response message for a webhook call.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type WebhookResponse = src.WebhookResponse

// Represents a fulfillment response to the user.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type WebhookResponse_FulfillmentResponse = src.WebhookResponse_FulfillmentResponse

// Defines merge behavior for `messages`.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type WebhookResponse_FulfillmentResponse_MergeBehavior = src.WebhookResponse_FulfillmentResponse_MergeBehavior
type WebhookResponse_TargetFlow = src.WebhookResponse_TargetFlow
type WebhookResponse_TargetPage = src.WebhookResponse_TargetPage

// Represents configuration for a generic web service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Webhook_GenericWebService = src.Webhook_GenericWebService
type Webhook_GenericWebService_ = src.Webhook_GenericWebService_
type Webhook_ServiceDirectory = src.Webhook_ServiceDirectory

// Represents configuration for a [Service
// Directory](https://cloud.google.com/service-directory) service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type Webhook_ServiceDirectoryConfig = src.Webhook_ServiceDirectoryConfig

// WebhooksClient is the client API for Webhooks service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type WebhooksClient = src.WebhooksClient

// WebhooksServer is the server API for Webhooks service.
//
// Deprecated: Please use types in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
type WebhooksServer = src.WebhooksServer

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewAgentsClient(cc grpc.ClientConnInterface) AgentsClient { return src.NewAgentsClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewChangelogsClient(cc grpc.ClientConnInterface) ChangelogsClient {
	return src.NewChangelogsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewDeploymentsClient(cc grpc.ClientConnInterface) DeploymentsClient {
	return src.NewDeploymentsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewEntityTypesClient(cc grpc.ClientConnInterface) EntityTypesClient {
	return src.NewEntityTypesClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewEnvironmentsClient(cc grpc.ClientConnInterface) EnvironmentsClient {
	return src.NewEnvironmentsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewExperimentsClient(cc grpc.ClientConnInterface) ExperimentsClient {
	return src.NewExperimentsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewFlowsClient(cc grpc.ClientConnInterface) FlowsClient { return src.NewFlowsClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewIntentsClient(cc grpc.ClientConnInterface) IntentsClient { return src.NewIntentsClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewPagesClient(cc grpc.ClientConnInterface) PagesClient { return src.NewPagesClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewSecuritySettingsServiceClient(cc grpc.ClientConnInterface) SecuritySettingsServiceClient {
	return src.NewSecuritySettingsServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewSessionEntityTypesClient(cc grpc.ClientConnInterface) SessionEntityTypesClient {
	return src.NewSessionEntityTypesClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewSessionsClient(cc grpc.ClientConnInterface) SessionsClient { return src.NewSessionsClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewTestCasesClient(cc grpc.ClientConnInterface) TestCasesClient {
	return src.NewTestCasesClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewTransitionRouteGroupsClient(cc grpc.ClientConnInterface) TransitionRouteGroupsClient {
	return src.NewTransitionRouteGroupsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewVersionsClient(cc grpc.ClientConnInterface) VersionsClient { return src.NewVersionsClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func NewWebhooksClient(cc grpc.ClientConnInterface) WebhooksClient { return src.NewWebhooksClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterAgentsServer(s *grpc.Server, srv AgentsServer) { src.RegisterAgentsServer(s, srv) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterChangelogsServer(s *grpc.Server, srv ChangelogsServer) {
	src.RegisterChangelogsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterDeploymentsServer(s *grpc.Server, srv DeploymentsServer) {
	src.RegisterDeploymentsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterEntityTypesServer(s *grpc.Server, srv EntityTypesServer) {
	src.RegisterEntityTypesServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterEnvironmentsServer(s *grpc.Server, srv EnvironmentsServer) {
	src.RegisterEnvironmentsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterExperimentsServer(s *grpc.Server, srv ExperimentsServer) {
	src.RegisterExperimentsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterFlowsServer(s *grpc.Server, srv FlowsServer) { src.RegisterFlowsServer(s, srv) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterIntentsServer(s *grpc.Server, srv IntentsServer) { src.RegisterIntentsServer(s, srv) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterPagesServer(s *grpc.Server, srv PagesServer) { src.RegisterPagesServer(s, srv) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterSecuritySettingsServiceServer(s *grpc.Server, srv SecuritySettingsServiceServer) {
	src.RegisterSecuritySettingsServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterSessionEntityTypesServer(s *grpc.Server, srv SessionEntityTypesServer) {
	src.RegisterSessionEntityTypesServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterSessionsServer(s *grpc.Server, srv SessionsServer) { src.RegisterSessionsServer(s, srv) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterTestCasesServer(s *grpc.Server, srv TestCasesServer) {
	src.RegisterTestCasesServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterTransitionRouteGroupsServer(s *grpc.Server, srv TransitionRouteGroupsServer) {
	src.RegisterTransitionRouteGroupsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterVersionsServer(s *grpc.Server, srv VersionsServer) { src.RegisterVersionsServer(s, srv) }

// Deprecated: Please use funcs in: cloud.google.com/go/dialogflow/cx/apiv3beta1/cxpb
func RegisterWebhooksServer(s *grpc.Server, srv WebhooksServer) { src.RegisterWebhooksServer(s, srv) }
